@@ -11,9 +11,7 @@ pub fn save(data: &[u8], private: bool) {
 }
 
 pub fn size() -> usize {
-    unsafe {
-        ffi::qwac_data_size() as usize
-    }
+    unsafe { ffi::qwac_data_size() as usize }
 }
 
 pub fn shared_size(cartridge_id: u128) -> usize {
@@ -25,15 +23,14 @@ pub fn shared_size(cartridge_id: u128) -> usize {
 
 /// Load the given data into given buffer
 pub fn load(data: &mut [u8]) -> usize {
-    unsafe {
-        ffi::qwac_data_load(data.as_mut_ptr(), data.len() as _) as usize
-    }
+    unsafe { ffi::qwac_data_load(data.as_mut_ptr(), data.len() as _) as usize }
 }
 
 pub fn shared_load(cartridge_id: u128, data: &mut [u8]) -> usize {
     unsafe {
         let cartridge_id = cartridge_id.to_be_bytes();
-        ffi::qwac_data_shared_load(cartridge_id.as_ptr(), data.as_mut_ptr(), data.len() as _) as usize
+        ffi::qwac_data_shared_load(cartridge_id.as_ptr(), data.as_mut_ptr(), data.len() as _)
+            as usize
     }
 }
 
@@ -49,7 +46,7 @@ pub fn load_vec() -> Vec<u8> {
 }
 
 #[cfg(feature = "alloc")]
-pub fn shared_load_vec(cartridge_id: u128,) -> Vec<u8> {
+pub fn shared_load_vec(cartridge_id: u128) -> Vec<u8> {
     let mut output = Vec::new();
     let size = shared_size(cartridge_id);
     if size > 0 {
