@@ -37,6 +37,21 @@ impl GridVector {
     }
 }
 
+impl From<(GridUnit, GridUnit)> for GridVector {
+    fn from(units: (GridUnit, GridUnit)) -> Self {
+        Self {
+            x: units.0,
+            y: units.1,
+        }
+    }
+}
+
+impl From<GridVector> for (GridUnit, GridUnit) {
+    fn from(vector: GridVector) -> Self {
+        (vector.x, vector.y)
+    }
+}
+
 #[derive(Default, Clone, Copy, Debug, PartialEq, PartialOrd)]
 pub struct Rectangle {
     pub origin: GridVector,
